package VMOMI::HostFirewallRuleProtocol;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
